@@ -36,7 +36,7 @@ cgettext = gettext.gettext
 
 # Tell gettext where to find localized strings.
 #
-localedir = os.path.join ("/opt/gnome", "share", "locale")
+localedir = os.path.join ("/home/jd/checkout/orca/bld", "share", "locale")
 gettext.bindtextdomain ("orca", localedir)
 gettext.textdomain("orca")
 
@@ -78,7 +78,8 @@ def setLocaleForMessages(newLocale=None):
 def setLocaleForNames(newLocale=None):
     modules = ['orca.chnames', 'orca.keynames', 'orca.phonnames',
                'orca.text_attribute_names', 'orca.object_properties',
-               'orca.cmdnames', 'orca.keybindings']
+               'orca.cmdnames', 'orca.keybindings', 'orca.colornames',
+               'orca.mathsymbols']
     for module in modules:
         setModuleLocale(module, newLocale)
 
