@@ -265,6 +265,20 @@ class SpeechGenerator(generator.Generator):
             result.extend(acss)
         return result
 
+    def _generateTable(self, obj, **args):
+        if _settingsManager.getSetting('onlySpeakDisplayedText'):
+            return []
+
+        if _settingsManager.getSetting('speechVerbosityLevel') == \
+           settings.VERBOSITY_LEVEL_BRIEF:
+            return []
+
+        acss = self.voice(SYSTEM)
+        result = generator.Generator._generateTable(self, obj, **args)
+        if result:
+            result.extend(acss)
+        return result
+
     def _generateTextRole(self, obj, **args):
         """A convenience method to prevent the pyatspi.ROLE_PARAGRAPH role
         from being spoken. In the case of a pyatspi.ROLE_PARAGRAPH
@@ -375,23 +389,6 @@ class SpeechGenerator(generator.Generator):
             result.extend(acss)
         return result
 
-    def _generateEmbedded(self, obj, **args):
-        """Returns an array of strings (and possibly voice and audio
-        specifications) used especially for handling embedded objects.
-        This either is the label or name of the object or the name of
-        the application for the object.
-        """
-        acss = self.voice(DEFAULT)
-        result = self._generateLabelOrName(obj, **args)
-        if not result:
-            try:
-                result.append(obj.getApplication().name)
-            except:
-                pass
-        if result:
-            result.extend(acss)
-        return result
-
     #####################################################################
     #                                                                   #
     # State information                                                 #
